# Contribute

For contributing to this project, please create pull requests or issues in this GitHub
[OpenStack Image Manager](https://github.com/osism/openstack-image-manager) repository.
To prioritize the import of a new image [Contact Us](mailto:info@osism.tech) with reference to the created pull request.
If you want to contribute to this documentation please do the same like described above.

After creating a pull request, please check the result of the Zuul Pipelines and correct any errors identified.
